|
|
|
|
|
|
| Synopsis |
|
|
|
|
| Tree structure
|
|
|
A tree representation that uses a monadic list as its child list type.
Note that you can use the type function ListOf to give a list of
any node type, using that node's associated list type, e.g.
ListOf (UNode Text)
|
|
|
The tree representation of the XML document.
c is the container type for the element's children, which is [] in the
hexpat package, and a monadic list type for hexpat-iteratee.
tag is the tag type, which can either be one of several string types,
or a special type from the Text.XML.Expat.Namespaced or
Text.XML.Expat.Qualified modules.
text is the string type for text content.
| | Constructors | | Element | | | eName :: !tag | | | eAttributes :: ![(tag, text)] | | | eChildren :: c (NodeG c tag text) | |
| | Text !text | |
| Instances | |
|
|
|
| Type alias for a single node with unqualified tag names where tag and
text are the same string type.
|
|
| Generic node manipulation
|
|
| module Text.XML.Expat.Internal.NodeClass |
|
| Generic manipulation of the child list
|
|
| module Data.List.Class |
|
| Qualified nodes
|
|
|
| Type alias for a single annotated node where qualified names are used for tags
|
|
| module Text.XML.Expat.Internal.Qualified |
|
| Namespaced nodes
|
|
|
| Type alias for a single annotated node where namespaced names are used for tags
|
|
| module Text.XML.Expat.Internal.Namespaced |
|
| Parse to tree
|
|
| data ParserOptions tag text | Source |
|
| Constructors | | ParserOptions | | | parserEncoding :: Maybe Encoding | The encoding parameter, if provided, overrides the document's
encoding declaration.
| | entityDecoder :: Maybe (tag -> Maybe text) | If provided, entity references (i.e. and friends) will
be decoded into text using the supplied lookup function
|
|
|
|
|
|
|
|
| Encoding types available for the document encoding.
| | Constructors | |
|
|
|
An iteratee that parses the input document, passing a representation of it
to the specified handler monad. The monad runs lazily using co-routines, so
if it requests a part of the tree that hasn't been parsed yet, it will
be suspended, and continued when it's available.
This implementation does not use Haskell's lazy I/O.
|
|
|
| The monad transformer used for writing your handler for chunked XML trees,
which executes as a co-routine.
| | Constructors | | XMLT | | | runXMLT :: m (Result m a) | |
|
| Instances | |
|
|
|
| Parse error, consisting of message text and error location
| | Constructors | | Instances | |
|
|
|
| Specifies a location of an event within the input text
| | Constructors | | XMLParseLocation | | | xmlLineNumber :: Int64 | Line number of the event
| | xmlColumnNumber :: Int64 | Column number of the event
| | xmlByteIndex :: Int64 | Byte index of event from start of document
| | xmlByteCount :: Int64 | The number of bytes in the event
|
|
| Instances | |
|
|
| Produced by Haddock version 2.6.1 |